using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Media;
using Microsoft.Xna.Framework.Net;
using Microsoft.Xna.Framework.Storage;

namespace Cyberbots2349
{
    class Game1 : Microsoft.Xna.Framework.Game
    {
        GraphicsDeviceManager graphics;

        Texture2D backgroundTexture;    //holds background
        Texture2D startTexture;         //holds start screen
        Rectangle viewportRect;         //for screen size
        SpriteBatch spriteBatch;        //for drawing background and sprites

        Characters alien;               //object for the player

        Characters[] Chasers;           //object lists for robots, humans and lasers
        Characters[] StrongChasers;
        Characters[] FastChasers;
        Characters[] Titans;
        Characters[] Zappers;
        Characters[] Humans;
        Characters[] Lasers;
        Characters Laser1;
        Characters Laser2;

        int lvl1Bots = 30;  //number of bots in each lvl
        int lvl2Bots = 40;  //will be used to determine when level ends
        int lvl3Bots = 50;  //by decrementing each time a robot is killed
        int lvl4Bots = 60;
        int lvl5Bots = 70;

        int points = 0;     //for score display
        int live = 3;       //for lives display
        int level = 0;      //for stage display

        bool started = false;   //to determine whether starting screen is to be shown
        bool win = false;       //has player won
        bool lose = false;      //has player lost
        bool pause = false;     //for pauses between games
        
        int scoreTemp = 0;  //score holder for new life awards
        int index = 0;      //a general index

        SpriteFont scoreFont;           //font for score display
        SpriteFont livesFont;           //font for lives display
        SpriteFont stageFont;           //font for stage display
        SpriteFont robotFont;           //font for remaining robots display

        Vector2 score = new Vector2(0.1f, 0.1f);    //for score display 
        Vector2 lives = new Vector2(0.1f, 0.1f);    //for lives display
        Vector2 stage = new Vector2(0.1f, 0.1f);    //for stage display
        Vector2 robot = new Vector2(0.1f, 0.1f);    //for remaining robots display

        AudioEngine audioEngine;    //for sounds
        WaveBank waveBank;
        SoundBank soundBank;

        System.Random RandNum = new System.Random();    //for random numbers
        int rand;

        public Game1()
        {
            graphics = new GraphicsDeviceManager(this);
            Content.RootDirectory = "Content";

            //set framerate
            TargetElapsedTime = new TimeSpan(0, 0, 0, 0, 100);
        }

        protected override void Initialize()
        {
            base.Initialize();
        }

        protected override void LoadContent()
        {
            //pause for win/lose screens
            if (pause == true)
            {
                //pause for 8 seconds
                System.Threading.Thread.Sleep(8 * 1000);

                pause = false;
            }

            if (level == 0)
            {
                level = 1;

                //load audio
                audioEngine = new AudioEngine(@"Content\Sounds\CyberbotSound.xgs");
                waveBank = new WaveBank(audioEngine, @"Content\Sounds\Wave Bank.xwb");
                soundBank = new SoundBank(audioEngine, @"Content\Sounds\Sound Bank.xsb");

                spriteBatch = new SpriteBatch(graphics.GraphicsDevice);

                //load background image
                backgroundTexture = Content.Load<Texture2D>
                    ("Art\\Screen");

                //load start screen image
                startTexture = Content.Load<Texture2D>
                    ("Art\\Start");

                //load player controlled sprite image
                alien = new Alien(Content.Load<Texture2D>
                    ("Art\\Alien"));

                //starting player position at center of play area
                alien.position = new Vector2(400, 330);

                //load sprites for chasers
                Chasers = new Chaser[30];
                for (index = 0; index < 30; index++)
                {
                    Chasers[index] = new Chaser(Content.Load<Texture2D>
                                    ("Art\\Chaser"));
                }

                //load sprites for strong chasers
                StrongChasers = new StrongChaser[10];
                for (index = 0; index < 10; index++)
                {
                    StrongChasers[index] = new StrongChaser(Content.Load<Texture2D>
                                    ("Art\\ChaserStrong"));
                }

                //load sprites for fast chasers
                FastChasers = new FastChaser[10];
                for (index = 0; index < 10; index++)
                {
                    FastChasers[index] = new FastChaser(Content.Load<Texture2D>
                                    ("Art\\ChaserFast"));
                }

                //load sprites for titans
                Titans = new Titan[10];
                for (index = 0; index < 10; index++)
                {
                    Titans[index] = new Titan(Content.Load<Texture2D>
                                    ("Art\\Titan"));
                }

                //load sprites for zappers
                Zappers = new Zapper[10];
                for (index = 0; index < 10; index++)
                {
                    Zappers[index] = new Zapper(Content.Load<Texture2D>
                                    ("Art\\Zapper"));
                }

                //load sprites for humans
                Humans = new Human[10];
                for (index = 0; index < 10; index++)
                {
                    //generate random number 1 or 2
                    rand = RandNum.Next(2);

                    //if its 1, make male human
                    if (rand == 1)
                    {
                        Humans[index] = new Human(Content.Load<Texture2D>
                                    ("Art\\HumanMale"));
                    }
                    //if its 2, make female human
                    else
                    {
                        Humans[index] = new Human(Content.Load<Texture2D>
                                    ("Art\\HumanFemale"));
                    }
                }

                //load sprites for lasers
                Lasers = new Laser[30];
                for (index = 0; index < 30; index++)
                {
                    Lasers[index] = new Laser(Content.Load<Texture2D>
                                    ("Art\\Laser"));
                }

                //load sprite for laser type 1
                Laser1 = new Laser1(Content.Load<Texture2D>
                                    ("Art\\Laser"));

                //load sprite for laser type 2
                Laser2 = new Laser2(Content.Load<Texture2D>
                                    ("Art\\Laser2"));

                for (index = 0; index < 30; index++)
                {
                    //get chasers ready to be drawn on screen
                    Chasers[index].life = -1;
                }

                for (index = 0; index < 10; index++)
                {
                    //get humans ready to be drawn on screen
                    Humans[index].life = -1;
                }

                //activate level 1 bots
                ChaserPos();
                HumanPos();

                //load font for score
                scoreFont = Content.Load<SpriteFont>
                    ("Fonts\\Score");

                //load font for lives remaining
                livesFont = Content.Load<SpriteFont>
                    ("Fonts\\Lives");

                //load font for current stage
                stageFont = Content.Load<SpriteFont>
                    ("Fonts\\Stage");

                //load font for remaining robots
                robotFont = Content.Load<SpriteFont>
                    ("Fonts\\Robots");

                //load screen, set size
                viewportRect = new Rectangle(0, 0,
                    graphics.GraphicsDevice.Viewport.Width,
                    graphics.GraphicsDevice.Viewport.Height);
            }
            else if (level == 1)
            {
                //starting player position at center of play area
                alien.position = new Vector2(400, 330);

                //reset level 1 bots
                ChaserPos();
                HumanPos();
            }
            else if (level == 2)
            {
                //starting player position at center of play area
                alien.position = new Vector2(400, 330);

                //reset level 2 bots
                ChaserPos();
                SChaserPos();
                HumanPos();
            }
            else if (level == 3)
            {
                //starting player position at center of play area
                alien.position = new Vector2(400, 330);

                //reset level 3 bots
                ChaserPos();
                SChaserPos();
                FChaserPos();
                HumanPos();
            }
            else if (level == 4)
            {
                //starting player position at center of play area
                alien.position = new Vector2(400, 330);

                //reset level 4 bots
                ChaserPos();
                SChaserPos();
                FChaserPos();
                TitanPos();
                HumanPos();
            }
            else if (level == 5)
            {
                //starting player position at center of play area
                alien.position = new Vector2(400, 330);

                //reset level 5 bots
                ChaserPos();
                SChaserPos();
                FChaserPos();
                TitanPos();
                ZapperPos();
                HumanPos();
            }

            base.LoadContent();
        }

        protected void ChaserPos()
        {
            Chasers[0].position.X = 100;
            Chasers[0].position.Y = 150;

            Chasers[1].position.X = 300;
            Chasers[1].position.Y = 100;

            Chasers[2].position.X = 500;
            Chasers[2].position.Y = 100;

            Chasers[3].position.X = 700;
            Chasers[3].position.Y = 150;

            Chasers[4].position.X = 100;
            Chasers[4].position.Y = 500;

            Chasers[5].position.X = 300;
            Chasers[5].position.Y = 550;

            Chasers[6].position.X = 500;
            Chasers[6].position.Y = 550;

            Chasers[7].position.X = 700;
            Chasers[7].position.Y = 500;

            Chasers[8].position.X = 100;
            Chasers[8].position.Y = 330;

            Chasers[9].position.X = 700;
            Chasers[9].position.Y = 330;

            Chasers[10].position.X = 50;
            Chasers[10].position.Y = 150;

            Chasers[11].position.X = 250;
            Chasers[11].position.Y = 100;

            Chasers[12].position.X = 450;
            Chasers[12].position.Y = 100;

            Chasers[13].position.X = 650;
            Chasers[13].position.Y = 150;

            Chasers[14].position.X = 50;
            Chasers[14].position.Y = 550;

            Chasers[15].position.X = 250;
            Chasers[15].position.Y = 500;

            Chasers[16].position.X = 450;
            Chasers[16].position.Y = 500;

            Chasers[17].position.X = 650;
            Chasers[17].position.Y = 550;

            Chasers[18].position.X = 100;
            Chasers[18].position.Y = 230;

            Chasers[19].position.X = 700;
            Chasers[19].position.Y = 230;

            Chasers[20].position.X = 150;
            Chasers[20].position.Y = 150;

            Chasers[21].position.X = 350;
            Chasers[21].position.Y = 100;

            Chasers[22].position.X = 550;
            Chasers[22].position.Y = 100;

            Chasers[23].position.X = 750;
            Chasers[23].position.Y = 150;

            Chasers[24].position.X = 150;
            Chasers[24].position.Y = 550;

            Chasers[25].position.X = 350;
            Chasers[25].position.Y = 500;

            Chasers[26].position.X = 550;
            Chasers[26].position.Y = 500;

            Chasers[27].position.X = 750;
            Chasers[27].position.Y = 550;

            Chasers[28].position.X = 100;
            Chasers[28].position.Y = 430;

            Chasers[29].position.X = 700;
            Chasers[29].position.Y = 430;

            for (index = 0; index < 30; index++)
            {
                if (Chasers[index].life == -1 || Chasers[index].life > 0)
                {
                    Chasers[index].life = 1;
                }
            }
        }

        protected void SChaserPos()
        {
            StrongChasers[0].position.X = 100;
            StrongChasers[0].position.Y = 150;

            StrongChasers[1].position.X = 300;
            StrongChasers[1].position.Y = 100;

            StrongChasers[2].position.X = 500;
            StrongChasers[2].position.Y = 100;

            StrongChasers[3].position.X = 700;
            StrongChasers[3].position.Y = 150;

            StrongChasers[4].position.X = 100;
            StrongChasers[4].position.Y = 550;

            StrongChasers[5].position.X = 300;
            StrongChasers[5].position.Y = 500;

            StrongChasers[6].position.X = 500;
            StrongChasers[6].position.Y = 500;

            StrongChasers[7].position.X = 700;
            StrongChasers[7].position.Y = 550;

            StrongChasers[8].position.X = 100;
            StrongChasers[8].position.Y = 330;

            StrongChasers[9].position.X = 700;
            StrongChasers[9].position.Y = 330;

            for (index = 0; index < 10; index++)
            {
                if (StrongChasers[index].life == -1 || StrongChasers[index].life > 0)
                {
                    StrongChasers[index].life = 4;
                }
            }
        }

        protected void FChaserPos()
        {
            FastChasers[0].position.X = 100;
            FastChasers[0].position.Y = 100;

            FastChasers[1].position.X = 300;
            FastChasers[1].position.Y = 100;

            FastChasers[2].position.X = 500;
            FastChasers[2].position.Y = 100;

            FastChasers[3].position.X = 700;
            FastChasers[3].position.Y = 100;

            FastChasers[4].position.X = 100;
            FastChasers[4].position.Y = 525;

            FastChasers[5].position.X = 300;
            FastChasers[5].position.Y = 525;

            FastChasers[6].position.X = 500;
            FastChasers[6].position.Y = 525;

            FastChasers[7].position.X = 700;
            FastChasers[7].position.Y = 525;

            FastChasers[8].position.X = 100;
            FastChasers[8].position.Y = 355;

            FastChasers[9].position.X = 700;
            FastChasers[9].position.Y = 355;
            
            for (index = 0; index < 10; index++)
            {
                if (FastChasers[index].life == -1 || FastChasers[index].life > 0)
                {
                    FastChasers[index].life = 1;
                }
            }
        }

        protected void TitanPos()
        {
            Titans[0].position.X = 100;
            Titans[0].position.Y = 200;

            Titans[1].position.X = 300;
            Titans[1].position.Y = 200;

            Titans[2].position.X = 500;
            Titans[2].position.Y = 200;

            Titans[3].position.X = 700;
            Titans[3].position.Y = 200;

            Titans[4].position.X = 100;
            Titans[4].position.Y = 425;

            Titans[5].position.X = 300;
            Titans[5].position.Y = 425;

            Titans[6].position.X = 500;
            Titans[6].position.Y = 425;

            Titans[7].position.X = 700;
            Titans[7].position.Y = 425;

            Titans[8].position.X = 100;
            Titans[8].position.Y = 350;

            Titans[9].position.X = 700;
            Titans[9].position.Y = 350;

            for (index = 0; index < 10; index++)
            {
                if (Titans[index].life == -1 || Titans[index].life > 0)
                {
                    Titans[index].life = 8;
                }
            }
        }

        protected void ZapperPos()
        {
            Zappers[0].position.X = 100;
            Zappers[0].position.Y = 150;

            Zappers[1].position.X = 300;
            Zappers[1].position.Y = 100;

            Zappers[2].position.X = 500;
            Zappers[2].position.Y = 100;

            Zappers[3].position.X = 700;
            Zappers[3].position.Y = 150;

            Zappers[4].position.X = 100;
            Zappers[4].position.Y = 550;

            Zappers[5].position.X = 300;
            Zappers[5].position.Y = 500;

            Zappers[6].position.X = 500;
            Zappers[6].position.Y = 500;

            Zappers[7].position.X = 700;
            Zappers[7].position.Y = 550;

            Zappers[8].position.X = 100;
            Zappers[8].position.Y = 330;

            Zappers[9].position.X = 700;
            Zappers[9].position.Y = 330;

            for (index = 0; index < 10; index++)
            {
                if (Zappers[index].life == -1 || Zappers[index].life > 0)
                {
                    Zappers[index].life = 1;
                }
            }
        }

        protected void HumanPos()
        {
            Humans[0].position.X = 100;
            Humans[0].position.Y = 250;

            Humans[1].position.X = 300;
            Humans[1].position.Y = 200;

            Humans[2].position.X = 500;
            Humans[2].position.Y = 200;

            Humans[3].position.X = 700;
            Humans[3].position.Y = 250;

            Humans[4].position.X = 100;
            Humans[4].position.Y = 500;

            Humans[5].position.X = 300;
            Humans[5].position.Y = 450;

            Humans[6].position.X = 500;
            Humans[6].position.Y = 450;

            Humans[7].position.X = 700;
            Humans[7].position.Y = 500;

            Humans[8].position.X = 300;
            Humans[8].position.Y = 330;

            Humans[9].position.X = 500;
            Humans[9].position.Y = 330;
            
            for (index = 0; index < 10; index++)
            {
                if (Humans[index].life == -1 || Humans[index].life > 0)
                {
                    Humans[index].life = 1;
                }
            }
        }

        protected void MoveBots()
        {
            float x = 0;        //for zapper targeting
            float y = 0;
            float targX = 0;
            float targY = 0;

            int destroyed = 0;  //counts bots destroyed this loop

            int index2 = 0;

            //chasers
            for (index = 0; index < 30; index++)
            {
                //if chaser is alive this loop
                if (Chasers[index].life > 0)
                {
                    //increment movement timer
                    Chasers[index].timer++;

                    //check for collision with player
                    if (((Chasers[index].position.X - (Chasers[index].sprite.Width / 2)) - (alien.position.X + (alien.sprite.Width / 2))) <= 0 &&
                        ((alien.position.X - (alien.sprite.Width / 2)) - (Chasers[index].position.X + (Chasers[index].sprite.Width / 2))) <= 0 &&
                        ((Chasers[index].position.Y - (Chasers[index].sprite.Height / 2)) - (alien.position.Y + (alien.sprite.Height / 2))) <= 0 &&
                        ((alien.position.Y - (alien.sprite.Height / 2)) - (Chasers[index].position.Y + (Chasers[index].sprite.Height / 2))) <= 0)
                    {
                        //remove 1 life from player
                        live--;

                        //play explosion sound
                        soundBank.PlayCue("explosion");

                        //pause for 3 seconds
                        System.Threading.Thread.Sleep(3 * 1000);

                        //remove live lasers
                        KillLasers();

                        //reload level with remaining bots
                        LoadContent();
                    }
                    //move bot
                    else if (Chasers[index].timer == 5)
                    {
                        //move the chaser
                        if (alien.position.X > Chasers[index].position.X)
                        {
                            Chasers[index].position.X += Chasers[index].velocity.X;
                        }
                        else if (alien.position.X < Chasers[index].position.X)
                        {
                            Chasers[index].position.X -= Chasers[index].velocity.X;
                        }

                        if (alien.position.Y > Chasers[index].position.Y)
                        {
                            Chasers[index].position.Y += Chasers[index].velocity.Y;
                        }
                        else if (alien.position.Y < Chasers[index].position.Y)
                        {
                            Chasers[index].position.Y -= Chasers[index].velocity.Y;
                        }

                        //reset timer
                        Chasers[index].timer = 0;

                        //checking right boundary collision
                        if ((Chasers[index].position.X + (Chasers[index].sprite.Width / 2)) >= 775)
                            Chasers[index].position.X = (775 - (Chasers[index].sprite.Width / 2));

                        //checking bottom boundary collision
                        if ((Chasers[index].position.Y + (Chasers[index].sprite.Height / 2)) >= 575)
                            Chasers[index].position.Y = (575 - (Chasers[index].sprite.Height / 2));

                        //checking left boundary collision
                        if ((Chasers[index].position.X - (Chasers[index].sprite.Width / 2)) <= 25)
                            Chasers[index].position.X = (25 + (Chasers[index].sprite.Width / 2));

                        //checking top boundary collision
                        if ((Chasers[index].position.Y - (Chasers[index].sprite.Height / 2)) <= 55)
                            Chasers[index].position.Y = (55 + (Chasers[index].sprite.Height / 2));
                    }
                }
            }

            if (level == 2 || level == 3 || level == 4 || level == 5)
            {
                //strong chasers
                for (index = 0; index < 10; index++)
                {
                    //if strong chaser is alive this loop
                    if (StrongChasers[index].life > 0)
                    {
                        //increment movement timer
                        StrongChasers[index].timer++;

                        //check for collision with player
                        if (((StrongChasers[index].position.X - (StrongChasers[index].sprite.Width / 2)) - (alien.position.X + (alien.sprite.Width / 2))) <= 0 &&
                            ((alien.position.X - (alien.sprite.Width / 2)) - (StrongChasers[index].position.X + (StrongChasers[index].sprite.Width / 2))) <= 0 &&
                            ((StrongChasers[index].position.Y - (StrongChasers[index].sprite.Height / 2)) - (alien.position.Y + (alien.sprite.Height / 2))) <= 0 &&
                            ((alien.position.Y - (alien.sprite.Height / 2)) - (StrongChasers[index].position.Y + (StrongChasers[index].sprite.Height / 2))) <= 0)
                        {
                            //remove 1 life from player
                            live--;

                            //play explosion sound
                            soundBank.PlayCue("explosion");

                            //pause for 3 seconds
                            System.Threading.Thread.Sleep(3 * 1000);

                            //remove live lasers
                            KillLasers();

                            //reload level with remaining bots
                            LoadContent();
                        }
                        //move bot
                        else if (StrongChasers[index].timer == 5)
                        {
                            //move the strong chaser
                            if (alien.position.X > StrongChasers[index].position.X)
                            {
                                StrongChasers[index].position.X += StrongChasers[index].velocity.X;
                            }
                            else if (alien.position.X < StrongChasers[index].position.X)
                            {
                                StrongChasers[index].position.X -= StrongChasers[index].velocity.X;
                            }

                            if (alien.position.Y > StrongChasers[index].position.Y)
                            {
                                StrongChasers[index].position.Y += StrongChasers[index].velocity.Y;
                            }
                            else if (alien.position.Y < StrongChasers[index].position.Y)
                            {
                                StrongChasers[index].position.Y -= StrongChasers[index].velocity.Y;
                            }

                            //reset timer
                            StrongChasers[index].timer = 0;

                            //checking right boundary collision
                            if ((StrongChasers[index].position.X + (StrongChasers[index].sprite.Width / 2)) >= 775)
                                StrongChasers[index].position.X = (775 - (StrongChasers[index].sprite.Width / 2));

                            //checking bottom boundary collision
                            if ((StrongChasers[index].position.Y + (StrongChasers[index].sprite.Height / 2)) >= 575)
                                StrongChasers[index].position.Y = (575 - (StrongChasers[index].sprite.Height / 2));

                            //checking left boundary collision
                            if ((StrongChasers[index].position.X - (StrongChasers[index].sprite.Width / 2)) <= 25)
                                StrongChasers[index].position.X = (25 + (StrongChasers[index].sprite.Width / 2));

                            //checking top boundary collision
                            if ((StrongChasers[index].position.Y - (StrongChasers[index].sprite.Height / 2)) <= 55)
                                StrongChasers[index].position.Y = (55 + (StrongChasers[index].sprite.Height / 2));
                        }
                    }
                }
            }

            if (level == 3 || level == 4 || level == 5)
            {
                //fast chasers
                for (index = 0; index < 10; index++)
                {
                    //if fast chaser is alive this loop
                    if (FastChasers[index].life > 0)
                    {
                        //increment movement timer
                        FastChasers[index].timer++;

                        //check for collision with player
                        if (((FastChasers[index].position.X - (FastChasers[index].sprite.Width / 2)) - (alien.position.X + (alien.sprite.Width / 2))) <= 0 &&
                            ((alien.position.X - (alien.sprite.Width / 2)) - (FastChasers[index].position.X + (FastChasers[index].sprite.Width / 2))) <= 0 &&
                            ((FastChasers[index].position.Y - (FastChasers[index].sprite.Height / 2)) - (alien.position.Y + (alien.sprite.Height / 2))) <= 0 &&
                            ((alien.position.Y - (alien.sprite.Height / 2)) - (FastChasers[index].position.Y + (FastChasers[index].sprite.Height / 2))) <= 0)
                        {
                            //remove 1 life from player
                            live--;

                            //play explosion sound
                            soundBank.PlayCue("explosion");

                            //pause for 3 seconds
                            System.Threading.Thread.Sleep(3 * 1000);

                            //remove live lasers
                            KillLasers();

                            //reload level with remaining bots
                            LoadContent();
                        }
                        //move bot
                        else if (FastChasers[index].timer == 3)
                        {
                            //move the fast chaser
                            if (alien.position.X > FastChasers[index].position.X)
                            {
                                FastChasers[index].position.X += FastChasers[index].velocity.X;
                            }
                            else if (alien.position.X < FastChasers[index].position.X)
                            {
                                FastChasers[index].position.X -= FastChasers[index].velocity.X;
                            }

                            if (alien.position.Y > FastChasers[index].position.Y)
                            {
                                FastChasers[index].position.Y += FastChasers[index].velocity.Y;
                            }
                            else if (alien.position.Y < FastChasers[index].position.Y)
                            {
                                FastChasers[index].position.Y -= FastChasers[index].velocity.Y;
                            }

                            //reset timer
                            FastChasers[index].timer = 0;

                            //checking right boundary collision
                            if ((FastChasers[index].position.X + (FastChasers[index].sprite.Width / 2)) >= 775)
                                FastChasers[index].position.X = (775 - (FastChasers[index].sprite.Width / 2));

                            //checking bottom boundary collision
                            if ((FastChasers[index].position.Y + (FastChasers[index].sprite.Height / 2)) >= 575)
                                FastChasers[index].position.Y = (575 - (FastChasers[index].sprite.Height / 2));

                            //checking left boundary collision
                            if ((FastChasers[index].position.X - (FastChasers[index].sprite.Width / 2)) <= 25)
                                FastChasers[index].position.X = (25 + (FastChasers[index].sprite.Width / 2));

                            //checking top boundary collision
                            if ((FastChasers[index].position.Y - (FastChasers[index].sprite.Height / 2)) <= 55)
                                FastChasers[index].position.Y = (55 + (FastChasers[index].sprite.Height / 2));
                        }
                    }
                }
            }

            if (level == 4 || level == 5)
            {
                //titans
                for (index = 0; index < 10; index++)
                {
                    //if titan is alive this loop
                    if (Titans[index].life > 0)
                    {
                        //increment movement timer
                        Titans[index].timer++;

                        //check for collision with player
                        if (((Titans[index].position.X - (Titans[index].sprite.Width / 2)) - (alien.position.X + (alien.sprite.Width / 2))) <= 0 &&
                            ((alien.position.X - (alien.sprite.Width / 2)) - (Titans[index].position.X + (Titans[index].sprite.Width / 2))) <= 0 &&
                            ((Titans[index].position.Y - (Titans[index].sprite.Height / 2)) - (alien.position.Y + (alien.sprite.Height / 2))) <= 0 &&
                            ((alien.position.Y - (alien.sprite.Height / 2)) - (Titans[index].position.Y + (Titans[index].sprite.Height / 2))) <= 0)
                        {
                            //remove 1 life from player
                            live--;

                            //play explosion sound
                            soundBank.PlayCue("explosion");

                            //pause for 3 seconds
                            System.Threading.Thread.Sleep(3 * 1000);

                            //remove live lasers
                            KillLasers();

                            //reload level with remaining bots
                            LoadContent();
                        }
                        //move bot
                        else if (Titans[index].timer == 3)
                        {
                            //move the titan in X direction
                            x = RandNum.Next(2);
                            if (x == 1)
                            {
                                Titans[index].position.X += Titans[index].velocity.X;
                            }
                            else Titans[index].position.X -= Titans[index].velocity.X;

                            //move the titan in y direction
                            x = RandNum.Next(2);
                            if (x == 1)
                            {
                                Titans[index].position.Y += Titans[index].velocity.Y;
                            }
                            else Titans[index].position.Y -= Titans[index].velocity.Y;

                            //reset timer
                            Titans[index].timer = 0;

                            //checking right boundary collision
                            if ((Titans[index].position.X + (Titans[index].sprite.Width / 2)) >= 775)
                                Titans[index].position.X = (775 - (Titans[index].sprite.Width / 2));

                            //checking bottom boundary collision
                            if ((Titans[index].position.Y + (Titans[index].sprite.Height / 2)) >= 575)
                                Titans[index].position.Y = (575 - (Titans[index].sprite.Height / 2));

                            //checking left boundary collision
                            if ((Titans[index].position.X - (Titans[index].sprite.Width / 2)) <= 25)
                                Titans[index].position.X = (25 + (Titans[index].sprite.Width / 2));

                            //checking top boundary collision
                            if ((Titans[index].position.Y - (Titans[index].sprite.Height / 2)) <= 55)
                                Titans[index].position.Y = (55 + (Titans[index].sprite.Height / 2));
                        }
                    }
                }
            }

            if (level == 5)
            {
                //zappers
                for (index = 0; index < 10; index++)
                {
                    //if zapper is alive this loop
                    if (Zappers[index].life > 0)
                    {
                        //increment timer
                        Zappers[index].timer++;

                        //check for collision with player
                        if (((Zappers[index].position.X - (Zappers[index].sprite.Width / 2)) - (alien.position.X + (alien.sprite.Width / 2))) <= 0 &&
                            ((alien.position.X - (alien.sprite.Width / 2)) - (Zappers[index].position.X + (Zappers[index].sprite.Width / 2))) <= 0 &&
                            ((Zappers[index].position.Y - (Zappers[index].sprite.Height / 2)) - (alien.position.Y + (alien.sprite.Height / 2))) <= 0 &&
                            ((alien.position.Y - (alien.sprite.Height / 2)) - (Zappers[index].position.Y + (Zappers[index].sprite.Height / 2))) <= 0)
                        {
                            //remove 1 life from player
                            live--;

                            //play explosion sound
                            soundBank.PlayCue("explosion");

                            //pause for 3 seconds
                            System.Threading.Thread.Sleep(3 * 1000);

                            //remove live lasers
                            KillLasers();

                            //reload level with remaining bots
                            LoadContent();
                        }
                        //move bot and shoot at player
                        else if (Zappers[index].timer == 15)
                        {
                            //x and y axis distances from player to zapper
                            x = alien.position.X - Zappers[index].position.X;
                            y = alien.position.Y - Zappers[index].position.Y;

                            //lasers velocity in x and y axis depending on distance in each direction
                            targX = (30 * (x / (x + y)));
                            targY = (30 * (y / (x + y)));

                            //fire laser
                            MakeLaser(targX, targY, Zappers[index].position.X, Zappers[index].position.Y, false);

                            //move the zapper in X direction
                            x = RandNum.Next(2);
                            if (x == 1)
                            {
                                Zappers[index].position.X += Zappers[index].velocity.X;
                            }
                            else Zappers[index].position.X -= Zappers[index].velocity.X;

                            //move the zapper in y direction
                            x = RandNum.Next(2);
                            if (x == 1)
                            {
                                Zappers[index].position.Y += Zappers[index].velocity.Y;
                            }
                            else Zappers[index].position.Y -= Zappers[index].velocity.Y;

                            //reset timer
                            Zappers[index].timer = 0;

                            //checking right boundary collision
                            if ((Zappers[index].position.X + (Zappers[index].sprite.Width / 2)) >= 775)
                                Zappers[index].position.X = (775 - (Zappers[index].sprite.Width / 2));

                            //checking bottom boundary collision
                            if ((Zappers[index].position.Y + (Zappers[index].sprite.Height / 2)) >= 575)
                                Zappers[index].position.Y = (576 - (Zappers[index].sprite.Height / 2));

                            //checking left boundary collision
                            if ((Zappers[index].position.X - (Zappers[index].sprite.Width / 2)) <= 25)
                                Zappers[index].position.X = (25 + (Zappers[index].sprite.Width / 2));

                            //checking top boundary collision
                            if ((Zappers[index].position.Y - (Zappers[index].sprite.Height / 2)) <= 55)
                                Zappers[index].position.Y = (55 + (Zappers[index].sprite.Height / 2));
                        }
                    }
                }
            }

            //humans
            for (index = 0; index < 10; index++)
            {
                //if human is alive this loop
                if (Humans[index].life > 0)
                {
                    //increment move timer
                    Humans[index].timer++;

                    //check for collision with player
                    if (((Humans[index].position.X - (Humans[index].sprite.Width / 2)) - (alien.position.X + (alien.sprite.Width / 2))) <= 0 &&
                        ((alien.position.X - (alien.sprite.Width / 2)) - (Humans[index].position.X + (Humans[index].sprite.Width / 2))) <= 0 &&
                        ((Humans[index].position.Y - (Humans[index].sprite.Height / 2)) - (alien.position.Y + (alien.sprite.Height / 2))) <= 0 &&
                        ((alien.position.Y - (alien.sprite.Height / 2)) - (Humans[index].position.Y + (Humans[index].sprite.Height / 2))) <= 0)
                    {
                        //if so, remove person and award player points
                        Humans[index].life--;
                        points += 500;
                        scoreTemp += 500;

                        //play hello sound
                        soundBank.PlayCue("hello");
                    }
                    //move human
                    else if (Humans[index].timer == 10)
                    {
                        //move the human in X direction
                        rand = RandNum.Next(2);
                        if (rand == 1)
                        {
                            Humans[index].position.X += Humans[index].velocity.X;
                        }
                        else Humans[index].position.X -= Humans[index].velocity.X;

                        //move the human in y direction
                        rand = RandNum.Next(2);
                        if (rand == 1)
                        {
                            Humans[index].position.Y += Humans[index].velocity.Y;
                        }
                        else Humans[index].position.Y -= Humans[index].velocity.Y;

                        //reset timer
                        Humans[index].timer = 0;

                        //checking right boundary collision
                        if ((Humans[index].position.X + (Humans[index].sprite.Width / 2)) >= 775)
                            Humans[index].position.X = (775 - (Humans[index].sprite.Width / 2));

                        //checking bottom boundary collision
                        if ((Humans[index].position.Y + (Humans[index].sprite.Height / 2)) >= 575)
                            Humans[index].position.Y = (575 - (Humans[index].sprite.Height / 2));

                        //checking left boundary collision
                        if ((Humans[index].position.X - (Humans[index].sprite.Width / 2)) <= 25)
                            Humans[index].position.X = (25 + (Humans[index].sprite.Width / 2));

                        //checking top boundary collision
                        if ((Humans[index].position.Y - (Humans[index].sprite.Height / 2)) <= 55)
                            Humans[index].position.Y = (55 + (Humans[index].sprite.Height / 2));
                    }
                }
            }

            //lasers
            for (index2 = 0; index2 < 30; index2++)
            {
                //if laser is alive
                if (Lasers[index2].life == 1)
                {
                    //if laser is enemy fire
                    if (Lasers[index2].faction == false)
                    {
                        //check for collision with player
                        if (((Lasers[index2].position.X - (Lasers[index2].sprite.Width / 2)) - (alien.position.X + (alien.sprite.Width / 2))) <= 0 &&
                            ((alien.position.X - (alien.sprite.Width / 2)) - (Lasers[index2].position.X + (Lasers[index2].sprite.Width / 2))) <= 0 &&
                            ((Lasers[index2].position.Y - (Lasers[index2].sprite.Height / 2)) - (alien.position.Y + (alien.sprite.Height / 2))) <= 0 &&
                            ((alien.position.Y - (alien.sprite.Height / 2)) - (Lasers[index2].position.Y + (Lasers[index2].sprite.Height / 2))) <= 0)
                        {
                            //if so, destroy laser and remove life from player
                            Lasers[index2].life = 0;
                            live--;

                            //play explosion sound
                            soundBank.PlayCue("explosion");

                            //pause for 3 seconds
                            System.Threading.Thread.Sleep(3 * 1000);

                            //remove live lasers
                            KillLasers();

                            //reload level with remaining bots
                            LoadContent();
                        }

                        //check collision with humans
                        for (index = 0; index < 10; index++)
                        {
                            if (Humans[index].life > 0)
                            {
                                if (((Lasers[index2].position.X - (Lasers[index2].sprite.Width / 2)) - (Humans[index].position.X + (Humans[index].sprite.Width / 2))) <= 0 &&
                                    ((Humans[index].position.X - (Humans[index].sprite.Width / 2)) - (Lasers[index2].position.X + (Lasers[index2].sprite.Width / 2))) <= 0 &&
                                    ((Lasers[index2].position.Y - (Lasers[index2].sprite.Height / 2)) - (Humans[index].position.Y + (Humans[index].sprite.Height / 2))) <= 0 &&
                                    ((Humans[index].position.Y - (Humans[index].sprite.Height / 2)) - (Lasers[index2].position.Y + (Lasers[index2].sprite.Height / 2))) <= 0)
                                {
                                    //if collision, destroy laser and human
                                    Lasers[index2].life = 0;
                                    Humans[index].life--;

                                    //play oh no sound
                                    soundBank.PlayCue("ohno");
                                }
                            }
                        }
                    }

                    //if laser is players
                    if (Lasers[index2].faction == true)
                    {
                        //check collision with chasers
                        for (index = 0; index < 30; index++)
                        {
                            if (Chasers[index].life > 0)
                            {
                                if (((Lasers[index2].position.X - (Lasers[index2].sprite.Width / 2)) - (Chasers[index].position.X + (Chasers[index].sprite.Width / 2))) <= 0 &&
                                    ((Chasers[index].position.X - (Chasers[index].sprite.Width / 2)) - (Lasers[index2].position.X + (Lasers[index2].sprite.Width / 2))) <= 0 &&
                                    ((Lasers[index2].position.Y - (Lasers[index2].sprite.Height / 2)) - (Chasers[index].position.Y + (Chasers[index].sprite.Height / 2))) <= 0 &&
                                    ((Chasers[index].position.Y - (Chasers[index].sprite.Height / 2)) - (Lasers[index2].position.Y + (Lasers[index2].sprite.Height / 2))) <= 0)
                                {
                                    //if collision, destroy laser and remove life from bot
                                    Lasers[index2].life = 0;
                                    Chasers[index].life--;

                                    //award points
                                    points += 100;
                                    scoreTemp += 100;

                                    //play explosion sound
                                    soundBank.PlayCue("explosion");

                                    //bot was destroyed
                                    destroyed++;
                                }
                            }
                        }

                        //check collision with strong chasers
                        for (index = 0; index < 10; index++)
                        {
                            if (StrongChasers[index].life > 0)
                            {
                                if (((Lasers[index2].position.X - (Lasers[index2].sprite.Width / 2)) - (StrongChasers[index].position.X + (StrongChasers[index].sprite.Width / 2))) <= 0 &&
                                    ((StrongChasers[index].position.X - (StrongChasers[index].sprite.Width / 2)) - (Lasers[index2].position.X + (Lasers[index2].sprite.Width / 2))) <= 0 &&
                                    ((Lasers[index2].position.Y - (Lasers[index2].sprite.Height / 2)) - (StrongChasers[index].position.Y + (StrongChasers[index].sprite.Height / 2))) <= 0 &&
                                    ((StrongChasers[index].position.Y - (StrongChasers[index].sprite.Height / 2)) - (Lasers[index2].position.Y + (Lasers[index2].sprite.Height / 2))) <= 0)
                                {
                                    //if collision, destroy laser and remove life from bot
                                    Lasers[index2].life = 0;
                                    StrongChasers[index].life--;

                                    //award points and play explosion sound if strong chaser dies
                                    if (StrongChasers[index].life == 0)
                                    {
                                        points += 200;
                                        scoreTemp += 200;

                                        soundBank.PlayCue("explosion");

                                        //bot was destroyed
                                        destroyed++;
                                    }
                                }
                            }
                        }

                        //check collision with fast chasers
                        for (index = 0; index < 10; index++)
                        {
                            if (FastChasers[index].life > 0)
                            {
                                if (((Lasers[index2].position.X - (Lasers[index2].sprite.Width / 2)) - (FastChasers[index].position.X + (FastChasers[index].sprite.Width / 2))) <= 0 &&
                                    ((FastChasers[index].position.X - (FastChasers[index].sprite.Width / 2)) - (Lasers[index2].position.X + (Lasers[index2].sprite.Width / 2))) <= 0 &&
                                    ((Lasers[index2].position.Y - (Lasers[index2].sprite.Height / 2)) - (FastChasers[index].position.Y + (FastChasers[index].sprite.Height / 2))) <= 0 &&
                                    ((FastChasers[index].position.Y - (FastChasers[index].sprite.Height / 2)) - (Lasers[index2].position.Y + (Lasers[index2].sprite.Height / 2))) <= 0)
                                {
                                    //if collision, destroy laser and remove life from bot
                                    Lasers[index2].life = 0;
                                    FastChasers[index].life--;

                                    //award points
                                    points += 200;
                                    scoreTemp += 200;

                                    //play explosion sound
                                    soundBank.PlayCue("explosion");

                                    //bot was destroyed
                                    destroyed++;
                                }
                            }
                        }

                        //check collision with titans
                        for (index = 0; index < 10; index++)
                        {
                            if (Titans[index].life > 0)
                            {
                                if (((Lasers[index2].position.X - (Lasers[index2].sprite.Width / 2)) - (Titans[index].position.X + (Titans[index].sprite.Width / 2))) <= 0 &&
                                    ((Titans[index].position.X - (Titans[index].sprite.Width / 2)) - (Lasers[index2].position.X + (Lasers[index2].sprite.Width / 2))) <= 0 &&
                                    ((Lasers[index2].position.Y - (Lasers[index2].sprite.Height / 2)) - (Titans[index].position.Y + (Titans[index].sprite.Height / 2))) <= 0 &&
                                    ((Titans[index].position.Y - (Titans[index].sprite.Height / 2)) - (Lasers[index2].position.Y + (Lasers[index2].sprite.Height / 2))) <= 0)
                                {
                                    //if collision, destroy laser and remove life from bot
                                    Lasers[index2].life = 0;
                                    Titans[index].life--;

                                    //award points and play explosion sound if titan dies
                                    if (Titans[index].life == 0)
                                    {
                                        points += 500;
                                        scoreTemp += 500;

                                        soundBank.PlayCue("explosion");

                                        //bot was destroyed
                                        destroyed++;
                                    }
                                }
                            }
                        }

                        //check collision with zappers
                        for (index = 0; index < 10; index++)
                        {
                            if (Zappers[index].life > 0)
                            {
                                if (((Lasers[index2].position.X - (Lasers[index2].sprite.Width / 2)) - (Zappers[index].position.X + (Zappers[index].sprite.Width / 2))) <= 0 &&
                                    ((Zappers[index].position.X - (Zappers[index].sprite.Width / 2)) - (Lasers[index2].position.X + (Lasers[index2].sprite.Width / 2))) <= 0 &&
                                    ((Lasers[index2].position.Y - (Lasers[index2].sprite.Height / 2)) - (Zappers[index].position.Y + (Zappers[index].sprite.Height / 2))) <= 0 &&
                                    ((Zappers[index].position.Y - (Zappers[index].sprite.Height / 2)) - (Lasers[index2].position.Y + (Lasers[index2].sprite.Height / 2))) <= 0)
                                {
                                    //if collision, destroy laser and remove life from bot
                                    Lasers[index2].life = 0;
                                    Zappers[index].life--;

                                    //award points
                                    points += 300;
                                    scoreTemp += 300;

                                    //play explosion sound
                                    soundBank.PlayCue("explosion");

                                    //bot was destroyed
                                    destroyed++;
                                }
                            }
                        }

                        //check collision with humans
                        for (index = 0; index < 10; index++)
                        {
                            if (Humans[index].life > 0)
                            {
                                if (((Lasers[index2].position.X - (Lasers[index2].sprite.Width / 2)) - (Humans[index].position.X + (Humans[index].sprite.Width / 2))) <= 0 &&
                                    ((Humans[index].position.X - (Humans[index].sprite.Width / 2)) - (Lasers[index2].position.X + (Lasers[index2].sprite.Width / 2))) <= 0 &&
                                    ((Lasers[index2].position.Y - (Lasers[index2].sprite.Height / 2)) - (Humans[index].position.Y + (Humans[index].sprite.Height / 2))) <= 0 &&
                                    ((Humans[index].position.Y - (Humans[index].sprite.Height / 2)) - (Lasers[index2].position.Y + (Lasers[index2].sprite.Height / 2))) <= 0)
                                {
                                    //if collision, destroy laser and human
                                    Lasers[index2].life = 0;
                                    Humans[index].life--;

                                    //play oh no sound
                                    soundBank.PlayCue("ohno");
                                }
                            }
                        }
                    }

                    //move the laser
                    Lasers[index2].position.X += Lasers[index2].velocity.X;
                    Lasers[index2].position.Y += Lasers[index2].velocity.Y;

                    //checking for boundary collisions
                    if ((Lasers[index2].position.X + (Lasers[index2].sprite.Width / 2)) >= 775 ||
                        (Lasers[index2].position.Y + (Lasers[index2].sprite.Height / 2)) >= 575 ||
                        (Lasers[index2].position.X - (Lasers[index2].sprite.Width / 2)) <= 25 ||
                        (Lasers[index2].position.Y - (Lasers[index2].sprite.Height / 2)) <= 55)
                    {
                        Lasers[index2].life = 0;
                    }
                }

                //remove destroyed bots from remaining bots
                if (level == 1)
                {
                    lvl1Bots -= destroyed;
                }
                else if (level == 2)
                {
                    lvl2Bots -= destroyed;
                }
                else if (level == 3)
                {
                    lvl3Bots -= destroyed;
                }
                else if (level == 4)
                {
                    lvl4Bots -= destroyed;
                }
                else if (level == 5)
                {
                    lvl5Bots -= destroyed;
                }

                //reset destroyed robots counter
                destroyed = 0;
            }
        }

        protected void MakeLaser(float velX, float velY, float posX, float posY, bool fac)
        {
            int i = 0;

            //find a free laser object if there is one
            for (i = 0; i < 30; i++)
            {
                if (Lasers[i].life == 0)
                {
                    //set lasers rotation
                    if (velX == 0 && velY > 0)
                    {
                        Lasers[i].rotation = (float)Math.PI;
                    }
                    else if (velX == 0 && velY < 0)
                    {
                        Lasers[i].rotation = 0.0f;
                    }
                    else if (velX > 0 && velY == 0)
                    {
                        Lasers[i].rotation = 1.5f * (float)Math.PI;
                    }
                    else if (velX < 0 && velY == 0)
                    {
                        Lasers[i].rotation = .5f * (float)Math.PI;
                    }
                    else if (velX > 0 && velY > 0)
                    {
                        Lasers[i].rotation = 1.75f * (float)Math.PI;
                    }
                    else if (velX > 0 && velY < 0)
                    {
                        Lasers[i].rotation = 1.25f * (float)Math.PI;
                    }
                    else if (velX < 0 && velY > 0)
                    {
                        Lasers[i].rotation = .25f * (float)Math.PI;
                    }
                    else if (velX < 0 && velY < 0)
                    {
                        Lasers[i].rotation = .75f * (float)Math.PI;
                    }

                    //set its faction
                    Lasers[i].faction = fac;

                    //if laser is players
                    if (Lasers[i].faction == true)
                    {
                        //set its velocity
                        Lasers[i].velocity.X = velX;
                        Lasers[i].velocity.Y = velY;

                        //set to laser type 1
                        Lasers[i].sprite = Laser1.sprite;
                    }
                    //if laser is enemy fire
                    else
                    {   //make it slower
                        Lasers[i].velocity.X = velX / 4;
                        Lasers[i].velocity.Y = velY / 4;

                        //set to laser type 2
                        Lasers[i].sprite = Laser2.sprite;
                    }

                    //set its position
                    Lasers[i].position.X = posX;
                    Lasers[i].position.Y = posY;

                    //make sure laser is fired if player is near boundary
                    if ((Lasers[i].position.X - (Lasers[i].sprite.Width / 2)) <= 25)
                        Lasers[i].position.X = 26;
                    if ((Lasers[i].position.X + (Lasers[i].sprite.Width / 2)) >= 775)
                        Lasers[i].position.X = 774;
                    if ((Lasers[i].position.Y - (Lasers[i].sprite.Height / 2)) <= 55)
                        Lasers[i].position.Y = 56;
                    if ((Lasers[i].position.Y + (Lasers[i].sprite.Height / 2)) >= 575)
                        Lasers[i].position.Y = 574;

                    //make laser live
                    Lasers[i].life = 1;

                    //play laser sound
                    soundBank.PlayCue("laser");

                    //break out of for loop
                    break;
                }
            }
        }

        protected void KillLasers()
        {
            for (int i = 0; i < 30; i++)
            {
                Lasers[i].life = 0;
            }
        }

        protected override void Update(GameTime gameTime)
        {
            //allows the game to exit with xbox controller
            if (GamePad.GetState(PlayerIndex.One).Buttons.Back == ButtonState.Pressed)
                this.Exit();

            //pause for start screen
            if (pause == true)
            {
                //pause for 8 seconds
                System.Threading.Thread.Sleep(8 * 1000);

                pause = false;

                //draw level 1
                Draw(gameTime);
            }

            //if out of lives, game over
            if (live == -1)
            {
                lose = true;

                //reset data
                lvl1Bots = 30;
                lvl2Bots = 40;
                lvl3Bots = 50;
                lvl4Bots = 60;
                lvl5Bots = 70;
                points = 0;
                live = 3;
                level = 0;
                scoreTemp = 0;
                started = false;
                pause = true;

                //draw lose screen
                Draw(gameTime);
            }
            else
            {
                //if player earns another 10,000 points, add a life
                if (scoreTemp == 10000)
                {
                    live++;
                    scoreTemp = 0;
                }

                //for level transitions and winning
                if (level == 1 && lvl1Bots == 0)
                {
                    level = 2;

                    //remove live lasers
                    KillLasers();

                    //move alien back to center
                    alien.position.X = 400;
                    alien.position.Y = 330;

                    //get level 2 bots ready to be loaded on screen
                    for (index = 0; index < 30; index++)
                    {
                        Chasers[index].life = -1;
                    }

                    for (index = 0; index < 10; index++)
                    {
                        StrongChasers[index].life = -1;
                        Humans[index].life = -1;
                    }

                    //activate level 2 bots
                    ChaserPos();
                    SChaserPos();
                    HumanPos();

                    //pause for 2 seconds
                    System.Threading.Thread.Sleep(2 * 1000);
                }
                if (level == 2 && lvl2Bots == 0)
                {
                    level = 3;

                    //remove live lasers
                    KillLasers();

                    //move alien back to center
                    alien.position.X = 400;
                    alien.position.Y = 330;

                    //get level 3 bots ready to be loaded on screen
                    for (index = 0; index < 30; index++)
                    {
                        Chasers[index].life = -1;
                    }

                    for (index = 0; index < 10; index++)
                    {
                        StrongChasers[index].life = -1;
                        FastChasers[index].life = -1;
                        Humans[index].life = -1;
                    }

                    //activate level 3 bots
                    ChaserPos();
                    SChaserPos();
                    FChaserPos();
                    HumanPos();

                    //pause for 2 seconds
                    System.Threading.Thread.Sleep(2 * 1000);
                }
                if (level == 3 && lvl3Bots == 0)
                {
                    level = 4;

                    //remove live lasers
                    KillLasers();

                    //move alien back to center
                    alien.position.X = 400;
                    alien.position.Y = 330;

                    //get level 4 bots ready to be loaded on screen
                    for (index = 0; index < 30; index++)
                    {
                        Chasers[index].life = -1;
                    }

                    for (index = 0; index < 10; index++)
                    {
                        StrongChasers[index].life = -1;
                        FastChasers[index].life = -1;
                        Titans[index].life = -1;
                        Humans[index].life = -1;
                    }

                    //activate level 4 bots
                    ChaserPos();
                    SChaserPos();
                    FChaserPos();
                    TitanPos();
                    HumanPos();

                    //pause for 2 seconds
                    System.Threading.Thread.Sleep(2 * 1000);
                }
                if (level == 4 && lvl4Bots == 0)
                {
                    level = 5;

                    //remove live lasers
                    KillLasers();

                    //move alien back to center
                    alien.position.X = 400;
                    alien.position.Y = 330;

                    //get level 5 bots ready to be loaded on screen
                    for (index = 0; index < 30; index++)
                    {
                        Chasers[index].life = -1;
                    }

                    for (index = 0; index < 10; index++)
                    {
                        StrongChasers[index].life = -1;
                        FastChasers[index].life = -1;
                        Titans[index].life = -1;
                        Zappers[index].life = -1;
                        Humans[index].life = -1;
                    }

                    //activate level 5 bots
                    ChaserPos();
                    SChaserPos();
                    FChaserPos();
                    TitanPos();
                    ZapperPos();
                    HumanPos();

                    //pause for 2 seconds
                    System.Threading.Thread.Sleep(2 * 1000);
                }
                if (level == 5 && lvl5Bots == 0)
                {
                    //remove live lasers
                    KillLasers();

                    win = true;

                    //reset data
                    lvl1Bots = 30;
                    lvl2Bots = 40;
                    lvl3Bots = 50;
                    lvl4Bots = 60;
                    lvl5Bots = 70;
                    points = 0;
                    live = 3;
                    level = 0;
                    scoreTemp = 0;
                    started = false;
                    pause = true;

                    //draw win screen
                    Draw(gameTime);
                }

                GamePadState gamePadState = GamePad.GetState(PlayerIndex.One);

                //firing south with xbox
                if (gamePadState.Buttons.A == ButtonState.Pressed &&
                    !(gamePadState.Buttons.Y == ButtonState.Pressed) &&
                    !(gamePadState.Buttons.X == ButtonState.Pressed) &&
                    !(gamePadState.Buttons.B == ButtonState.Pressed))
                {
                    MakeLaser(0, 30, (alien.position.X - (alien.sprite.Width / 4)), (alien.position.Y - (alien.sprite.Height / 4)), true);
                }

                //firing north with xbox
                if (gamePadState.Buttons.Y == ButtonState.Pressed &&
                    !(gamePadState.Buttons.A == ButtonState.Pressed) &&
                    !(gamePadState.Buttons.X == ButtonState.Pressed) &&
                    !(gamePadState.Buttons.B == ButtonState.Pressed))
                {
                    MakeLaser(0, -30, (alien.position.X - (alien.sprite.Width / 4)), (alien.position.Y - (alien.sprite.Height / 4)), true);
                }

                //firing east with xbox
                if (gamePadState.Buttons.B == ButtonState.Pressed &&
                    !(gamePadState.Buttons.X == ButtonState.Pressed) &&
                    !(gamePadState.Buttons.Y == ButtonState.Pressed) &&
                    !(gamePadState.Buttons.A == ButtonState.Pressed))
                {
                    MakeLaser(30, 0, (alien.position.X - (alien.sprite.Width / 4)), (alien.position.Y - (alien.sprite.Height / 4)), true);
                }

                //firing west with xbox
                if (gamePadState.Buttons.X == ButtonState.Pressed &&
                    !(gamePadState.Buttons.B == ButtonState.Pressed) &&
                    !(gamePadState.Buttons.Y == ButtonState.Pressed) &&
                    !(gamePadState.Buttons.A == ButtonState.Pressed))
                {
                    MakeLaser(-30, 0, (alien.position.X - (alien.sprite.Width / 4)), (alien.position.Y - (alien.sprite.Height / 4)), true);
                }

                //firing southeast with xbox
                if (gamePadState.Buttons.A == ButtonState.Pressed &&
                    gamePadState.Buttons.B == ButtonState.Pressed &&
                    !(gamePadState.Buttons.Y == ButtonState.Pressed) &&
                    !(gamePadState.Buttons.X == ButtonState.Pressed))
                {
                    MakeLaser(15, 15, (alien.position.X - (alien.sprite.Width / 4)), (alien.position.Y - (alien.sprite.Height / 4)), true);
                }

                //firing southwest with xbox
                if (gamePadState.Buttons.A == ButtonState.Pressed &&
                    gamePadState.Buttons.X == ButtonState.Pressed &&
                    !(gamePadState.Buttons.Y == ButtonState.Pressed) &&
                    !(gamePadState.Buttons.B == ButtonState.Pressed))
                {
                    MakeLaser(-15, 15, (alien.position.X - (alien.sprite.Width / 4)), (alien.position.Y - (alien.sprite.Height / 4)), true);
                }

                //firing northeast with xbox
                if (gamePadState.Buttons.Y == ButtonState.Pressed &&
                    gamePadState.Buttons.B == ButtonState.Pressed &&
                    !(gamePadState.Buttons.A == ButtonState.Pressed) &&
                    !(gamePadState.Buttons.X == ButtonState.Pressed))
                {
                    MakeLaser(15, -15, (alien.position.X - (alien.sprite.Width / 4)), (alien.position.Y - (alien.sprite.Height / 4)), true);
                }

                //firing northwest with xbox
                if (gamePadState.Buttons.Y == ButtonState.Pressed &&
                    gamePadState.Buttons.X == ButtonState.Pressed &&
                    !(gamePadState.Buttons.A == ButtonState.Pressed) &&
                    !(gamePadState.Buttons.B == ButtonState.Pressed))
                {
                    MakeLaser(-15, -15, (alien.position.X - (alien.sprite.Width / 4)), (alien.position.Y - (alien.sprite.Height / 4)), true);
                }

                //moving the player using xbox controller
                alien.position.X += alien.velocity.X * gamePadState.ThumbSticks.Left.X;
                alien.position.Y -= alien.velocity.Y * gamePadState.ThumbSticks.Left.Y;

                //moving the player using xbox controller
                alien.position.X += alien.velocity.X * gamePadState.ThumbSticks.Left.X;
                alien.position.Y -= alien.velocity.Y * gamePadState.ThumbSticks.Left.Y;

                KeyboardState keyboardState = Keyboard.GetState();

                //firing south using keyboard
                if (keyboardState.IsKeyDown(Keys.S) &&
                    !(keyboardState.IsKeyDown(Keys.A)) &&
                    !(keyboardState.IsKeyDown(Keys.W)) &&
                    !(keyboardState.IsKeyDown(Keys.D)))
                {
                    MakeLaser(0, 30, (alien.position.X - (alien.sprite.Width / 4)), (alien.position.Y - (alien.sprite.Height / 4)), true);
                }

                //firing north using keyboard
                if (keyboardState.IsKeyDown(Keys.W) &&
                    !(keyboardState.IsKeyDown(Keys.A)) &&
                    !(keyboardState.IsKeyDown(Keys.S)) &&
                    !(keyboardState.IsKeyDown(Keys.D)))
                {
                    MakeLaser(0, -30, (alien.position.X - (alien.sprite.Width / 4)), (alien.position.Y - (alien.sprite.Height / 4)), true);
                }

                //firing east using keyboard
                if (keyboardState.IsKeyDown(Keys.D) &&
                    !(keyboardState.IsKeyDown(Keys.A)) &&
                    !(keyboardState.IsKeyDown(Keys.W)) &&
                    !(keyboardState.IsKeyDown(Keys.S)))
                {
                    MakeLaser(30, 0, (alien.position.X - (alien.sprite.Width / 4)), (alien.position.Y - (alien.sprite.Height / 4)), true);
                }

                //firing west using keyboard
                if (keyboardState.IsKeyDown(Keys.A) &&
                    !(keyboardState.IsKeyDown(Keys.S)) &&
                    !(keyboardState.IsKeyDown(Keys.W)) &&
                    !(keyboardState.IsKeyDown(Keys.D)))
                {
                    MakeLaser(-30, 0, (alien.position.X - (alien.sprite.Width / 4)), (alien.position.Y - (alien.sprite.Height / 4)), true);
                }

                //firing southeast using keyboard
                if (keyboardState.IsKeyDown(Keys.S) &&
                    keyboardState.IsKeyDown(Keys.D) &&
                    !(keyboardState.IsKeyDown(Keys.W)) &&
                    !(keyboardState.IsKeyDown(Keys.A)))
                {
                    MakeLaser(15, 15, (alien.position.X - (alien.sprite.Width / 4)), (alien.position.Y - (alien.sprite.Height / 4)), true);
                }

                //firing southwest using keyboard
                if (keyboardState.IsKeyDown(Keys.S) &&
                    keyboardState.IsKeyDown(Keys.A) &&
                    !(keyboardState.IsKeyDown(Keys.W)) &&
                    !(keyboardState.IsKeyDown(Keys.D)))
                {
                    MakeLaser(-15, 15, (alien.position.X - (alien.sprite.Width / 4)), (alien.position.Y - (alien.sprite.Height / 4)), true);
                }

                //firing northeast using keyboard
                if (keyboardState.IsKeyDown(Keys.W) &&
                    keyboardState.IsKeyDown(Keys.D) &&
                    !(keyboardState.IsKeyDown(Keys.A)) &&
                    !(keyboardState.IsKeyDown(Keys.S)))
                {
                    MakeLaser(15, -15, (alien.position.X - (alien.sprite.Width / 4)), (alien.position.Y - (alien.sprite.Height / 4)), true);
                }

                //firing northwest using keyboard
                if (keyboardState.IsKeyDown(Keys.W) &&
                    keyboardState.IsKeyDown(Keys.A) &&
                    !(keyboardState.IsKeyDown(Keys.S)) &&
                    !(keyboardState.IsKeyDown(Keys.D)))
                {
                    MakeLaser(-15, -15, (alien.position.X - (alien.sprite.Width / 4)), (alien.position.Y - (alien.sprite.Height / 4)), true);
                }

                //moving the player using keyboard
                if (keyboardState.IsKeyDown(Keys.Up))
                {
                    alien.position.Y -= alien.velocity.Y;
                }
                if (keyboardState.IsKeyDown(Keys.Down))
                {
                    alien.position.Y += alien.velocity.Y;
                }
                if (keyboardState.IsKeyDown(Keys.Left))
                {
                    alien.position.X -= alien.velocity.X;
                }
                if (keyboardState.IsKeyDown(Keys.Right))
                {
                    alien.position.X += alien.velocity.X;
                }

                //checking right boundary collision
                if ((alien.position.X + (alien.sprite.Width / 2)) >= 775)
                    alien.position.X = (775 - (alien.sprite.Width / 2));

                //checking bottom boundary collision
                if ((alien.position.Y + (alien.sprite.Height / 2)) >= 575)
                    alien.position.Y = (575 - (alien.sprite.Height / 2));

                //checking left boundary collision
                if ((alien.position.X - (alien.sprite.Width / 2)) <= 25)
                    alien.position.X = (25 + (alien.sprite.Width / 2));

                //checking top boundary collision
                if ((alien.position.Y - (alien.sprite.Height / 2)) <= 55)
                    alien.position.Y = (55 + (alien.sprite.Height / 2));

                //update all sprites
                MoveBots();
            }

            base.Update(gameTime);
        }

        protected override void Draw(GameTime gameTime)
        {
            graphics.GraphicsDevice.Clear(Color.CornflowerBlue);

            if (win == true)
            {
                win = false;

                //play starting music
                soundBank.PlayCue("win-lose");

                LoadContent();
            }
            else if (lose == true)
            {
                lose = false;

                //play starting music
                soundBank.PlayCue("win-lose");

                LoadContent();
            }
            else if (started == false)
            {
                started = true;
                pause = true;

                //play starting music
                soundBank.PlayCue("start");

                spriteBatch.Begin(SpriteBlendMode.AlphaBlend);

                //draw the start screen
                spriteBatch.Draw(startTexture, viewportRect, Color.White);

                spriteBatch.End();
            }
            else
            {
                spriteBatch.Begin(SpriteBlendMode.AlphaBlend);

                //draw the background
                spriteBatch.Draw(backgroundTexture, viewportRect, Color.White);

                //for each chaser
                for (index = 0; index < 30; index++)
                {
                    //if the bot is alive
                    if (Chasers[index].life > 0)
                    {
                        //draw bot
                        spriteBatch.Draw(Chasers[index].sprite,
                            Chasers[index].position,
                            null,
                            Color.White,
                            Chasers[index].rotation,
                            Chasers[index].center,
                            1.0f,
                            SpriteEffects.None, 0);
                    }
                }

                if (level == 2 || level == 3 || level == 4 || level == 5)
                {
                    //for each strong chaser
                    for (index = 0; index < 10; index++)
                    {
                        //if the bot is alive
                        if (StrongChasers[index].life > 0)
                        {
                            //draw bot
                            spriteBatch.Draw(StrongChasers[index].sprite,
                                StrongChasers[index].position,
                                null,
                                Color.White,
                                StrongChasers[index].rotation,
                                StrongChasers[index].center,
                                1.0f,
                                SpriteEffects.None, 0);
                        }
                    }
                }

                if (level == 3 || level == 4 || level == 5)
                {
                    //for each fast chaser
                    for (index = 0; index < 10; index++)
                    {
                        //if the bot is alive
                        if (FastChasers[index].life > 0)
                        {
                            //draw bot
                            spriteBatch.Draw(FastChasers[index].sprite,
                                FastChasers[index].position,
                                null,
                                Color.White,
                                FastChasers[index].rotation,
                                FastChasers[index].center,
                                1.0f,
                                SpriteEffects.None, 0);
                        }
                    }
                }

                if (level == 4 || level == 5)
                {
                    //for each titan
                    for (index = 0; index < 10; index++)
                    {
                        //if the bot is alive
                        if (Titans[index].life > 0)
                        {
                            //draw bot
                            spriteBatch.Draw(Titans[index].sprite,
                                Titans[index].position,
                                null,
                                Color.White,
                                Titans[index].rotation,
                                Titans[index].center,
                                1.0f,
                                SpriteEffects.None, 0);
                        }
                    }
                }

                if (level == 5)
                {
                    //for each zapper
                    for (index = 0; index < 10; index++)
                    {
                        //if the bot is alive
                        if (Zappers[index].life > 0)
                        {
                            //draw bot
                            spriteBatch.Draw(Zappers[index].sprite,
                                Zappers[index].position,
                                null,
                                Color.White,
                                Zappers[index].rotation,
                                Zappers[index].center,
                                1.0f,
                                SpriteEffects.None, 0);
                        }
                    }
                }

                //for each human
                for (index = 0; index < 10; index++)
                {
                    //if the human is alive
                    if (Humans[index].life > 0)
                    {
                        //draw human
                        spriteBatch.Draw(Humans[index].sprite,
                             Humans[index].position,
                             null,
                             Color.White,
                             Humans[index].rotation,
                             Humans[index].center,
                             1.0f,
                             SpriteEffects.None, 0);
                    }
                }

                //for each laser
                for (index = 0; index < 30; index++)
                {
                    //if the laser is alive
                    if (Lasers[index].life == 1)
                    {
                        //draw bot
                        spriteBatch.Draw(Lasers[index].sprite,
                            Lasers[index].position,
                            null,
                            Color.White,
                            Lasers[index].rotation,
                            Lasers[index].center,
                            1.0f,
                            SpriteEffects.None, 0);
                    }
                }

                //draw alien
                spriteBatch.Draw(alien.sprite,
                    alien.position,
                    null,
                    Color.White,
                    alien.rotation,
                    alien.center,
                    1.0f,
                    SpriteEffects.None, 0);

                //draw the font for score
                spriteBatch.DrawString(scoreFont,
                    "Score: " + points.ToString(),
                    new Vector2(score.X * viewportRect.Width - 50,
                                score.Y * viewportRect.Height - 50),
                        Color.Red);

                //draw the font for lives remaining
                spriteBatch.DrawString(livesFont,
                    "Lives: " + live.ToString(),
                    new Vector2((lives.X * viewportRect.Width - 50) + 200,
                                lives.Y * viewportRect.Height - 50),
                        Color.Red);

                //draw the font for current stage
                spriteBatch.DrawString(stageFont,
                    "Stage: " + level.ToString(),
                    new Vector2((stage.X * viewportRect.Width - 50) + 300,
                                stage.Y * viewportRect.Height - 50),
                        Color.Red);

                if (level == 1)
                {
                    //draw the font for remaining robots
                    spriteBatch.DrawString(robotFont,
                        "Robots Left: " + lvl1Bots.ToString(),
                        new Vector2((robot.X * viewportRect.Width - 50) + 400,
                                    robot.Y * viewportRect.Height - 50),
                            Color.Red);
                }
                if (level == 2)
                {
                    //draw the font for remaining robots
                    spriteBatch.DrawString(robotFont,
                        "Robots Left: " + lvl2Bots.ToString(),
                        new Vector2((robot.X * viewportRect.Width - 50) + 400,
                                    robot.Y * viewportRect.Height - 50),
                            Color.Red);
                }
                if (level == 3)
                {
                    //draw the font for remaining robots
                    spriteBatch.DrawString(robotFont,
                        "Robots Left: " + lvl3Bots.ToString(),
                        new Vector2((robot.X * viewportRect.Width - 50) + 400,
                                    robot.Y * viewportRect.Height - 50),
                            Color.Red);
                }
                if (level == 4)
                {
                    //draw the font for remaining robots
                    spriteBatch.DrawString(robotFont,
                        "Robots Left: " + lvl4Bots.ToString(),
                        new Vector2((robot.X * viewportRect.Width - 50) + 400,
                                    robot.Y * viewportRect.Height - 50),
                            Color.Red);
                }
                if (level == 5)
                {
                    //draw the font for remaining robots
                    spriteBatch.DrawString(robotFont,
                        "Robots Left: " + lvl5Bots.ToString(),
                        new Vector2((robot.X * viewportRect.Width - 50) + 400,
                                    robot.Y * viewportRect.Height - 50),
                            Color.Red);
                }

                spriteBatch.End();
            }

            base.Draw(gameTime);
        }
    }
}